# pylingdocs-gui

A rudimentary GUI editor for pylingdocs.

![License](https://img.shields.io/github/license/fmatter/pylingdocs-gui)
[![PyPI](https://img.shields.io/pypi/v/pylingdocs-gui.svg)](https://pypi.org/project/pylingdocs-gui)
![Versions](https://img.shields.io/pypi/pyversions/pylingdocs-gui)

Usage: Run `pylingdocs-gui` in your pylingdocs project.